---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE]"
labels: enhancement
assignees: ''

---

* **What are you trying to do?**

* **What feature or behavior is this required for?**

* **How could we solve this issue? (Not knowing is okay!)**

* **Anything else?**

cc @bhamail / @DarthHater
